import Vue from "vue"
import VueRouter from "vue-router"
import cookies from 'vue-cookies'
import { userStore } from '@/store/userInfo'

Vue.use(VueRouter)

// 重写push||replace方法
// 先将原始push方法复制
let originPush=VueRouter.prototype.push
let originReplace=VueRouter.prototype.replace
// 重写
VueRouter.prototype.push=function(location,res,rej){
  // 如果传了成功,失败的回调
  if(res && rej){
    originPush.call(this,location,res,rej)
  } else {
    originPush.call(this,location,()=>{},()=>{})
  }
}

VueRouter.prototype.replace=function(location,res,rej){
  if (res && rej) {
      originReplace.call(this, location, res, rej)
  } else {
      originReplace.call(this, location, () => { }, () => { })
  }
}

const router = new VueRouter({
  mode: "history",
  base: import.meta.env.BASE_URL,
  routes: [
    {
      path: "/",
      redirect: '/dashboard'
    },
    {
      path: "/login",
      name: "login",
      component: () => import("../views/Login.vue"),
      meta: {
        title: 'Log In PDF Tech Console'
      }
    },
    {
      path: "/non-admin-user",
      name: "noadmin",
      component: () => import("@/views/Noadmin.vue"),
      meta: {
        title: 'Non-admin User'
      }
    },
    {
      path: "/sign-up",
      name: "Create",
      component: () => import("../views/Create.vue"),
      meta: {
        title: 'Sign Up PDF Tech Console'
      }
    },
    {
      path: "/forget-password",
      name: "forgotPassword",
      component: () => import("../views/forgotpassword.vue"),
      meta: {
        title: 'Forget Password | PDF Tech Account'
      }
    },
    {
      path: '',
      name: 'container',
      component: () => import("../views/Container.vue"),
      children: [
        {
          path: "/dashboard",
          name: "dashboard",
          component: () => import("../views/Dashboard.vue"),
          meta: {
            title: 'Home | PDF Tech Console'
          }
        },
        {
          path: "/product",
          name: "productManagement",
          component: () => import("../views/ProductManagement.vue"),
          meta: {
            title: 'Product | PDF Tech Console'
          }
        },
        {
          path: "/manage-team",
          name: "ManageTeam",
          component: () => import("../views/TeamManagement/ManageTeam.vue"),
          meta: {
            title: 'Manage Team | PDF Tech Console'
          }
        },
        {
          path: "/manage-team/edit-team",
          name: "EditManageTeam",
          component: () => import("../views/TeamManagement/ManageTeamOperate.vue"),
          meta: {
            title: 'Manage Team | PDF Tech Console'
          }
        },
        {
          path: "/manage-team/create-team",
          name: "CreateManageTeam",
          component: () => import("../views/TeamManagement/ManageTeamOperate.vue"),
          meta: {
            title: 'Manage Team | PDF Tech Console'
          }
        },
        {
          path: "/manage-member",
          name: "ManageMember",
          component: () => import("../views/TeamManagement/ManageMember.vue"),
          meta: {
            title: 'Manage Member | PDF Tech Console'
          }
        },
        {
          path: "/manage-member/edit-member",
          name: "EditManageMember",
          component: () => import("../views/TeamManagement/ManageMember/EditManageMember.vue"),
          meta: {
            title: 'Manage Member | PDF Tech Console'
          }
        },
        {
          path: "/manage-member/add-member",
          name: "AddManageMember",
          component: () => import("../views/TeamManagement/ManageMember/AddManageMember.vue"),
          meta: {
            title: 'Manage Member | PDF Tech Console'
          }
        },
        {
          path: "/manage-admin",
          name: "manageAdmin",
          component: () => import("../views/manageAdmin.vue"),
          meta: {
            title: 'Manage Admin | PDF Tech Console'
          }
        },
        {
          path: "/manage-admin/edit-admin",
          name: "editAdmin",
          component: () => import("../views/MenageAdmin/editAdmin.vue"),
          meta: {
            title: 'Manage Admin | PDF Tech Console'
          }
        },
        {
          path: "/manage-admin/add-admin",
          name: "addAdmin",
          component: () => import("../views/MenageAdmin/addAdmin.vue"),
          meta: {
            title: 'Manage Admin | PDF Tech Console'
          }
        },
        {
          path: "/license-management",
          name: "licenseManage",
          component: () => import("../views/LicenseManage.vue"),
          meta: {
            title: 'Manage License | PDF Tech Console'
          }
        },
        {
          path: "/assign-license",
          name: "assignLicense",
          component: () => import("../views/Assignlicense.vue"),
          meta: {
            title: 'Manage License | PDF Tech Console'
          }
        },
        {
          path: "/batch-cancel-license",
          name: "volumeCancel",
          component: () => import("../views/VolumeCancel.vue"),
          meta: {
            title: 'Manage License | PDF Tech Console'
          }
        },
        {
          path: "/manage-device",
          name: "device",
          component: () => import("../views/Device.vue"),
          meta: {
            title: 'Manage Device | PDF Tech Console'
          }
        },
        {
          path: "/settings",
          name: "settings",
          component: () => import("../views/Settings.vue"),
          meta: {
            title: 'Console Settings | PDF Tech Console'
          }
        },
        {
          path: "/support",
          name: "support",
          component: () => import("../views/Support.vue"),
          meta: {
            title: 'Support | PDF Tech Console'
          }
        },
        {
          path: "/reseller-manage-product",
          name: "ResellerProduct",
          component: () => import("../views/Reseller/Product.vue"),
          meta: {
            title: 'Manage Product | PDF Tech Console for Reseller'
          }
        },
        {
          path: "/reseller-manage-license",
          name: "ResellerLicense",
          component: () => import("../views/Reseller/License.vue"),
          meta: {
            title: 'Manage License | PDF Tech Console for Reseller'
          }
        },
      ]
    },
    { // 当没有匹配到正确路由的时候，匹配404组件
      path: '*',
      name: "404",
      component: () => import("../views/notFind.vue"),
    }
  ],
})
router.beforeEach(async(to, from, next) => {
  // 设置title
  if (to && to.meta && to.meta.title) {
    document.title = to.meta.title
  }
  let head = document.getElementsByTagName('head')
  let meta = document.createElement('meta')
  document.querySelector('meta[name="keywords"]').setAttribute('content', 'PDF Tech Console allows you to manage products, teams, licenses, and devices. Join Volume License Program to access the PDF Tech Console now!')
  document.querySelector('meta[name="description"]').setAttribute('content', 'PDF Tech Console, manage licenses, assign licenses, cancel licenses, volume licenses')
  meta.content = to.meta.content
  head[0].appendChild(meta)

  const whiteList = ['/login', '/sign-up', '/non-admin-user', '/forget-password', '/upload-file']
  const token = cookies.get('accessToken')
  //路由守卫，进行权限判断
  if (token) {
    try {
      await userStore().getUserInfo()
      // 判断权限
      if (userStore().user.role?.indexOf("2") !== -1 || userStore().user.role?.indexOf("1") !== -1 || userStore().user.role?.indexOf("4") !== -1) {
        next()
      } else {
        next('/non-admin-user')
      }
      const init = await userStore().getInitorUpdate()
      if (!init) {
        next('/product')
      }
    } catch (error) {
      console.log(error)
      const { response } = error
      if (response && response.data) {
        const data = response.data
        if (data.code === 310 || data.code === 313) {
          cookies.remove('accessToken')
          next('/login')
        }
      }
      next()
    }
  } else {
    if (whiteList.indexOf(to.path) !== -1) {
      next()
    } else {
      next('/login')
    }
  }
})

export default router
