import { defineStore } from 'pinia'
import { get, post } from '../../utils/request'

export const userStore = defineStore('user', {
    state: () => ({
        user: JSON.parse(localStorage.getItem('userInfo')) || '',
        init: false
    }),
    getters: {
        getUser: (state) => state.user,
        getInit: (state) => state.init
    },
    actions: {
        async getInitorUpdate() {
            try {
                const res = await post('/pdf-tech/vppKeyFile/updateOrInit')
                if (res.data.code === 200 && res.data.result) {
                    this.setInit(true)
                } else {
                    this.setInit(false)
                }
                return this.init
            } catch (error) {
                this.setInit(false)
                return Promise.reject(error)
            }
        },
        setInit(value) {
            this.init = value
        },
        async getUserInfo() {
            try {
                const res = await get('/pdf-tech/vppMember/getMemberInfo')
                if (res.data.code === 200 && res.data.msg == 'success') {
                    this.setUserInfo(res.data.result)
                }
            } catch (error) {
                return Promise.reject(error)
            }
        },
        // 获取用户信息
        setUserInfo(user) {
            if (user) {
                this.user = {
                    userName: user.fullName,
                    email: user.email,
                    role: user.role,
                    area: user.area
                }
                localStorage.setItem('userInfo', JSON.stringify(this.user))
            } else {
                this.user = {
                    userName: '',
                    email: '',
                    role: ''
                }
            }
        },
        // 清除用户信息
        clearUserInfo() {
            this.user = ''
            localStorage.removeItem('userInfo')
        }
    }
})
